<!--危险源-报警率事件对比-->
<template>
  <div class="alarm-highest-event">
    <public-title title="危险源-报警率事件对比" />
    <div class="chart-container">
      <div id="alarm-highest-event-chart" style="width: 100%;height: 100%;" />
    </div>
  </div>
</template>

<script>
import * as echarts from 'echarts'
import {statisticsMaxPoliceEvent} from '@/api/device/earlyWarningMonitoring'
import PublicTitle from '../PublicTitle/index.vue'

export default {
  name: 'AlarmHighestEvent',
  components: {PublicTitle},
  data() {
    return {
      myChart: null,  // 图表实例对象
      chartData: {}
    }
  },
  created() {
    this.getChartData()
  },
  mounted() {
    this.myChart = echarts.init(document.getElementById('alarm-highest-event-chart'))
  },
  methods: {
    /**
     * @function getChartData 获取图表数据
     * @return {void}
     * */
    async getChartData() {
      const {value} = await statisticsMaxPoliceEvent()
      this.chartData = value
      this.$nextTick(_ => this.initEcharts())
    },

    // 初始化图表
    initEcharts() {
      this.myChart.setOption({
        color: ['#ffb37b', '#ff6e79'],
        tooltip: {
          trigger: 'item',
          textStyle: {
            fontSize: 14,
            color: '#606266'
          }
        },
        legend: {
          position: 'center',
          top: 0,
          textStyle: {
            fontSize: 14,
            color: '#606266'
          }
        },
        series: [
          {
            name: '报警率最高事件',
            type: 'pie',
            clockwise: false,
            startAngle: 90,
            radius: ['50%', '80%'],
            center: ['50%', '57%'],
            avoidLabelOverlap: false,
            itemStyle: {
              borderRadius: 10,
              borderColor: 'rgba(255,255,255,0)',
              borderWidth: 10
            },
            data: [
              {
                value: this.chartData?.monitorAlarn || 0,
                name: '监测报警数'
              },
              {
                value: this.chartData?.deviceAlarm || 0,
                name: '设备报警数'
              }
            ],
            label: {
              normal: {
                show: true,
                position: 'inside',
                formatter: ({percent}) => percent ? percent.toFixed(0) + '%' : '',
                textStyle: {
                  align: 'center',
                  fontSize: 14,
                  fontWeight: 'bolder',
                  color: '#fff'
                }
              }
            }
          }
        ]
      })
      //随着屏幕大小调节图表
      window.addEventListener('resize', _ => this.myChart.resize())
    }
  },
  beforeDestroy() {
    // 取消事件的监听
    window.removeEventListener('resize', _ => this.myChart.resize())
  }
}
</script>

<style lang="scss" scoped>
.alarm-highest-event {
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;

  .chart-container {
    flex: 1;
    width: 100%;
    box-sizing: border-box;
    padding: 15px 20px;
  }
}
</style>
